==> percona-server-mongodb_4.0.9.orig.tar.gz: percona-server-mongodb-4.0.9-4/src/mongo/db/storage/wiredtiger/wiredtiger_extensions.cpp <==

/**
 *    Copyright (C) 2018-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#include "mongo/platform/basic.h"

#include "mongo/db/storage/wiredtiger/wiredtiger_extensions.h"

#include "mongo/base/string_data.h"
#include "mongo/db/service_context.h"
#include "mongo/stdx/memory.h"

namespace mongo {

namespace {
const auto getConfigHooks = ServiceContext::declareDecoration<WiredTigerExtensions>();
}  // namespace

WiredTigerExtensions* WiredTigerExtensions::get(ServiceContext* service) {
    return &getConfigHooks(service);
}

std::string WiredTigerExtensions::getOpenExtensionsConfig() const {
    if (_wtExtensions.size() == 0) {
        return "";
    }

    StringBuilder extensions;
    extensions << "extensions=[";
    for (const auto& ext : _wtExtensions) {
        extensions << ext << ",";
    }
    extensions << "],";

    return extensions.str();
}

void WiredTigerExtensions::addExtension(StringData extensionConfigStr) {
    _wtExtensions.emplace_back(extensionConfigStr.toString());
}

}  // namespace mongo

==> percona-server-mongodb-36_3.6.20.orig.tar.gz: percona-server-mongodb-3.6.20-9.0/src/mongo/db/storage/wiredtiger/wiredtiger_extensions.cpp <==

/**
 *    Copyright (C) 2018-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#include "mongo/platform/basic.h"

#include "mongo/db/storage/wiredtiger/wiredtiger_extensions.h"

#include "mongo/base/init.h"
#include "mongo/base/string_data.h"
#include "mongo/db/encryption/encryption_options.h"
#include "mongo/db/service_context.h"
#include "mongo/stdx/memory.h"

namespace mongo {

MONGO_INITIALIZER_WITH_PREREQUISITES(SetWiredTigerExtensions, ("SetGlobalEnvironment"))
(InitializerContext* context) {
    auto configHooks = stdx::make_unique<WiredTigerExtensions>();
    // add Percona encryption extension
    if (encryptionGlobalParams.enableEncryption) {
        std::stringstream ss;
        ss << "local=(entry=percona_encryption_extension_init,early_load=true,config=(cipher=" << encryptionGlobalParams.encryptionCipherMode << "))";
        configHooks->addExtension(ss.str());
    }
    WiredTigerExtensions::set(getGlobalServiceContext(), std::move(configHooks));

    return Status::OK();
}

namespace {
const auto getConfigHooks =
    ServiceContext::declareDecoration<std::unique_ptr<WiredTigerExtensions>>();
}  // namespace

void WiredTigerExtensions::set(ServiceContext* service,
                               std::unique_ptr<WiredTigerExtensions> configHooks) {
    auto& hooks = getConfigHooks(service);
    invariant(configHooks);
    hooks = std::move(configHooks);
}

WiredTigerExtensions* WiredTigerExtensions::get(ServiceContext* service) {
    return getConfigHooks(service).get();
}

std::string WiredTigerExtensions::getOpenExtensionsConfig() const {
    if (_wtExtensions.size() == 0) {
        return "";
    }

    StringBuilder extensions;
    extensions << "extensions=[";
    for (const auto& ext : _wtExtensions) {
        extensions << ext << ",";
    }
    extensions << "],";

    return extensions.str();
}

void WiredTigerExtensions::addExtension(StringData extensionConfigStr) {
    _wtExtensions.emplace_back(extensionConfigStr.toString());
}

}  // namespace mongo
